<img src='imgs/OOIPY_Logo.png' align="right" width=150>

# OOIPY
![PEP8](https://github.com/ooipy/ooipy/workflows/PEP8/badge.svg?branch=master) ![unit test](https://github.com/ooipy/ooipy/workflows/unit%20test/badge.svg) [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.4276862.svg)](https://doi.org/10.5281/zenodo.4276862) [![Documentation Status](https://readthedocs.org/projects/ooipy/badge/?version=latest)](https://ooipy.readthedocs.io/en/latest/?badge=latest)



OOIPY is a python toolbox designed to aid in scientific analysis of Ocean Observatories Initiative (OOI) data. Some data (such as broadband hydrophone data) is not available through the OOI API (M2M). This package is designed to help with the acquiring of datasets from the OOI Raw Data Server. Additionally, tools to analyze the data, such as spectrogram and power spectral density plotting are also provided.

For information on usage and complete documentation, go to [OOIPY Documentation](https://ooipy.readthedocs.io/en/latest/)


